import { PasswordType } from "./index";
/**
 * Issues found during the PIN strength test.
 */
export declare enum PinTestIssue {
    /**
     * Not enough unique digits found.
     */
    NOT_UNIQUE = "NOT_UNIQUE",
    /**
     * Too much repeating characters.
     */
    REPEATING_CHARS = "REPEATING_CHARS",
    /**
     * There is a pattern in this pin (for example 1357)
     */
    PATTERN_FOUND = "PATTERN_FOUND",
    /**
     * Tested pin could be date (for example 2512 as birthday - 25th of december)
     */
    POSSIBLY_DATE = "POSSIBLY_DATE",
    /**
     * Tested pin is in TOP used pins (like 1234 as number 1 used pin).
     */
    FREQUENTLY_USED = "FREQUENTLY_USED"
}
/**
 * Object representing a PIN test result.
 */
export interface PinTestResult {
    /**
     * If `true` then you should warn user about weak PIN.
     */
    shouldWarnUserAboutWeakPin: boolean;
    /**
     * List of all issues found during the test.
     */
    issues: PinTestIssue[];
}
/**
 * Object providing interface to test strength of PIN or password. Right now, only
 * the function for PIN testing is provided.
 */
export declare class PowerAuthPassphraseMeter {
    /**
     * Test strength of PIN.
     * @param pin PIN to test. You can provide string or `PowerAuthPassword` object containing numbers only.
     * @returns `PinTestResult` object.
     * @throws `PowerAuthErrorCode.WRONG_PARAM` if PIN contains other characters than digits or its length is less than 4.
     */
    static testPin(pin: PasswordType): Promise<PinTestResult>;
}
