/**
 * The `PowerAuthDebug` class provides a various functionality that can
 * help application develoepr with debugging the problem with React Native PowerAuth mobile SDK.
 */
export declare class PowerAuthDebug {
    /**
     * Enable or disable detailed log with calls to native code. Be aware that this feature is
     * effective only if global __DEV__ constant is `true`.
     * @param traceFailure If set to `true`, then SDK will print a detailed error if native call fails.
     * @param traceEachCall If set to `true`, then SDK will print a detailed information about each call to the native code.
     */
    static traceNativeCodeCalls(traceFailure: boolean, traceEachCall?: boolean): void;
    /**
     * Function prints debug information about all native objects registered in native module. Note that the function
     * is effective ony if native module is compiled in DEBUG mode and if global `__DEV__` constant is `true`.
     * @param instanceId If provided, then prints only objects that belongs to PowerAuth instance with given identifier.
     */
    static dumpNativeObjects(instanceId?: string | undefined): Promise<void>;
    /**
     * Function converts any error into human readable string.
     * @param error Error to descrive.
     * @returns Error translated to human readable string.
     */
    static describeError(error: any): string;
}
