/**
 * Interface that contains configuration for RESTful API client used internally by SDK.
 */
export interface PowerAuthClientConfigurationType {
    /**
     * Defines whether unsecured connection is allowed. If not provided, then `false` is applied.
     */
    readonly enableUnsecureTraffic?: boolean;
    /**
     * Connection timeout in seconds. If not provided, then the connection timeout is set to 20 seconds.
     */
    readonly connectionTimeout?: number;
    /**
     * Read timeout in seconds. Be aware that this parameter is ignored on Apple platforms.
     * If not provided, then the read timeout is set to 20 seconds.
     */
    readonly readTimeout?: number;
}
/**
 * Class that is used to provide RESTful API client configuration.
 */
export declare class PowerAuthClientConfiguration implements PowerAuthClientConfigurationType {
    enableUnsecureTraffic: boolean;
    connectionTimeout: number;
    readTimeout: number;
    constructor();
    /**
     * @returns `PowerAuthClientConfiguration` with default values.
     */
    static default(): PowerAuthClientConfigurationType;
}
/**
 * Function create a frozen object implementing `ClientConfigurationType` with all properties set.
 * @param input Optional application's configuration. If not provided, then the default values are set.
 * @returns Frozen `ClientConfigurationType` interface with all properties set.
 */
export declare function buildClientConfiguration(input?: PowerAuthClientConfigurationType | undefined): Required<PowerAuthClientConfigurationType>;
