/**
 * Interface that contains configuration data for a single `PowerAuth` instance.
 */
export interface PowerAuthConfigurationType {
    /**
     * `APPLICATION_KEY` as defined in PowerAuth specification - a key identifying an application version.
     */
    readonly applicationKey: string;
    /**
     * `APPLICATION_SECRET` as defined in PowerAuth specification - a secret associated with an application version.
     */
    readonly applicationSecret: string;
    /**
     * `KEY_SERVER_MASTER_PUBLIC` as defined in PowerAuth specification - a master server public key.
     */
    readonly masterServerPublicKey: string;
    /**
     * Base URL to the PowerAuth Standard REST API (the URL part before `"/pa/..."`).
     */
    readonly baseEndpointUrl: string;
}
/**
 * Class representing a configuration of a single `PowerAuth` instance. The class implements
 * `ConfigurationType` interface, so can be used
 */
export declare class PowerAuthConfiguration implements PowerAuthConfigurationType {
    applicationKey: string;
    applicationSecret: string;
    masterServerPublicKey: string;
    baseEndpointUrl: string;
    /**
     * Construct configuration with required parameters.
     *
     * @param applicationKey `APPLICATION_KEY` as defined in PowerAuth specification - a key identifying an application version.
     * @param applicationSecret `APPLICATION_SECRET` as defined in PowerAuth specification - a secret associated with an application version.
     * @param masterServerPublicKey `KEY_SERVER_MASTER_PUBLIC` as defined in PowerAuth specification - a master server public key.
     * @param baseEndpointUrl Base URL to the PowerAuth Standard REST API (the URL part before `"/pa/..."`).
     */
    constructor(applicationKey: string, applicationSecret: string, masterServerPublicKey: string, baseEndpointUrl: string);
}
/**
 * Create frozen configuration from provided configuration object.
 * @param input Application provided configuration.
 * @returns Frozen configuration object.
 */
export declare function buildConfiguration(input: PowerAuthConfigurationType): PowerAuthConfigurationType;
